@@ -1,5 +1,4 @@
 import graphlib
-import io
 import logging
 import zipfile
 from contextlib import contextmanager
@@ -179,7 +178,7 @@ class ImportContainer(BaseContainer):
         # -------------------
         # Build object graph
 
-        sorter = graphlib.TopologicalSorter(None)
+        sorter: graphlib.TopologicalSorter[ObjectData] = graphlib.TopologicalSorter(None)
         for obj in self._objects.values():
             if obj.id not in self.__discarded_objects:
                 deps = [
@@ -202,7 +201,7 @@ class ImportContainer(BaseContainer):
             raise e
 
         while sorter.is_active():
-            ready_objects: Tuple[ObjectData] = sorter.get_ready()
+            ready_objects: Tuple[ObjectData, ...] = sorter.get_ready()
             if not len(ready_objects):
                 raise RuntimeError('Could not untangle the reference graph')
 
